Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMarc Delisle <marc@infomarc.info>2009-12-30 18:27:27 +0300
committerMarc Delisle <marc@infomarc.info>2009-12-30 18:27:27 +0300
commit87b994743bb8553161699d4ff7845a59da758a60 (patch)
tree540ab878dde6008deab98c24a0638a09af25776f /tbl_row_action.php
parentd63ed916fc1fb91adbf158e61297376b0f98477c (diff)
primary_key is really a WHERE clause (that works also on tables where no PK is defined)
Diffstat (limited to 'tbl_row_action.php')
-rw-r--r--tbl_row_action.php29
1 files changed, 14 insertions, 15 deletions
diff --git a/tbl_row_action.php b/tbl_row_action.php
index c2204a509d..d72c7d5373 100644
--- a/tbl_row_action.php
+++ b/tbl_row_action.php
@@ -79,13 +79,13 @@ require_once './libraries/header.inc.php';
if (!empty($submit_mult)) {
switch($submit_mult) {
case 'row_edit':
- // garvin: As we got the fields to be edited from the 'rows_to_delete'
- // checkbox, we use the index of it as the
- // indicating primary key. Then we built the array which is used for
- // the tbl_change.php script.
- $primary_key = array();
- foreach ($_REQUEST['rows_to_delete'] as $i_primary_key => $del_query) {
- $primary_key[] = urldecode($i_primary_key);
+ // garvin: As we got the fields to be edited from the
+ // 'rows_to_delete' checkbox, we use the index of it as the
+ // indicating WHERE clause. Then we build the array which is used
+ // for the tbl_change.php script.
+ $where_clause = array();
+ foreach ($_REQUEST['rows_to_delete'] as $i_where_clause => $del_query) {
+ $where_clause[] = urldecode($i_where_clause);
}
$active_page = 'tbl_change.php';
@@ -96,14 +96,13 @@ if (!empty($submit_mult)) {
// Needed to allow SQL export
$single_table = TRUE;
- //$sql_query = urldecode($sql_query);
- // garvin: As we got the fields to be edited from the 'rows_to_delete'
- // checkbox, we use the index of it as the
- // indicating primary key. Then we built the array which is used for
- // the tbl_change.php script.
- $primary_key = array();
- foreach ($_REQUEST['rows_to_delete'] as $i_primary_key => $del_query) {
- $primary_key[] = urldecode($i_primary_key);
+ // garvin: As we got the fields to be edited from the
+ // 'rows_to_delete' checkbox, we use the index of it as the
+ // indicating WHERE clause. Then we build the array which is used
+ // for the tbl_change.php script.
+ $where_clause = array();
+ foreach ($_REQUEST['rows_to_delete'] as $i_where_clause => $del_query) {
+ $where_clause[] = urldecode($i_where_clause);
}
$active_page = 'tbl_export.php';